@@ -1,5 +1,5 @@
 import os
-from pwd import getpwnam  
+from pwd import getpwnam
 import sys
 import click
 import tempfile
@@ -7,27 +7,31 @@ from pathlib import Path
 from contextlib import contextmanager
 from .odoo_config import MANIFEST
 
+
 def _get_settings_files(config):
     """
     Returns list of paths or files
     """
     from . import odoo_config
+
     customs_dir = config.WORKING_DIR
 
     if customs_dir:
-        yield customs_dir / 'settings'
-    yield Path('/etc/odoo/settings')
+        yield customs_dir / "settings"
+    yield Path("/etc/odoo/settings")
     if config.project_name:
-        yield Path(f'/etc/odoo/{config.project_name}/settings')
-    yield customs_dir / '.odoo' / 'settings'
-    yield Path(os.environ['HOME']) / '.odoo' / 'settings'
-    yield customs_dir / '.odoo' / 'run' / 'settings'
+        yield Path(f"/etc/odoo/{config.project_name}/settings")
+    yield customs_dir / ".odoo" / "settings"
+    yield Path(os.environ["HOME"]) / ".odoo" / "settings"
+    yield customs_dir / ".odoo" / "run" / "settings"
+
 
 @contextmanager
 def _get_settings(config, customs, quiet=False):
     from .myconfigparser import MyConfigParser  # NOQA
+
     files = _collect_settings_files(config, customs=None, quiet=quiet)
-    filename = tempfile.mktemp(suffix='.')
+    filename = tempfile.mktemp(suffix=".")
     _make_settings_file(filename, files)
     c = MyConfigParser(filename)
     try:
@@ -35,47 +39,46 @@ def _get_settings(config, customs, quiet=False):
     finally:
         Path(filename).unlink()
 
+
 def _export_settings(config, forced_values):
     from . import odoo_config
     from .myconfigparser import MyConfigParser
 
     setting_files = _collect_settings_files(config)
-    _make_settings_file(config.files['settings'], setting_files)
+    _make_settings_file(config.files["settings"], setting_files)
     # constants
-    settings = MyConfigParser(config.files['settings'])
-    if 'OWNER_UID' not in settings.keys():
+    settings = MyConfigParser(config.files["settings"])
+    if "OWNER_UID" not in settings.keys():
         UID = int(os.getenv("SUDO_UID", os.getuid()))
         if not UID:
             # sometimes (in ansible) SUDO_UID is set to 0 but env USER exists
-            if os.getenv("USER") and os.environ['USER'] != 'root':
-                UID = getpwnam(os.environ['USER']).pw_uid
-        settings['OWNER_UID'] = str(UID)
+            if os.getenv("USER") and os.environ["USER"] != "root":
+                UID = getpwnam(os.environ["USER"]).pw_uid
+        settings["OWNER_UID"] = str(UID)
 
     # forced values:
     for k, v in forced_values.items():
         settings[k] = v
 
-    settings['ODOO_IMAGES'] = config.dirs['images']
+    settings["ODOO_IMAGES"] = config.dirs["images"]
 
     settings.write()
 
+
 def _collect_settings_files(config, quiet=False):
     _files = []
 
     if config.dirs:
-        _files.append(config.dirs['odoo_home'] / 'defaults')
+        _files.append(config.dirs["odoo_home"] / "defaults")
         # optimize
-        for filename in config.dirs['images'].glob("**/default.settings"):
-            _files.append(config.dirs['images'] / filename)
-    if config.restrict['settings']:
-        _files += config.restrict['settings']
+        for filename in config.dirs["images"].glob("**/default.settings"):
+            _files.append(config.dirs["images"] / filename)
+    if config.restrict["settings"]:
+        _files += config.restrict["settings"]
     else:
-        if 'settings_auto' in _files:
-            _files.append(config.files['settings_auto'])
-
         for dir in filter(lambda x: x.exists(), _get_settings_files(config)):
             if not quiet:
-                click.secho("Searching for settings in: {}".format(dir), fg='cyan')
+                click.secho("Searching for settings in: {}".format(dir), fg="cyan")
             if dir.is_file():
                 _files.append(dir)
             elif dir.is_dir():
@@ -85,14 +88,19 @@ def _collect_settings_files(config, quiet=False):
                     _files.append(file)
 
         # _files.append(files['user_settings'])
-        if config.files and 'project_settings' in config.files:
-            if config.files['project_settings'].exists():
-                _files.append(config.files['project_settings'])
+        if config.files and "project_settings" in config.files:
+            if config.files["project_settings"].exists():
+                _files.append(config.files["project_settings"])
             else:
-                click.secho("Hint: file for configuration can be used: {}".format(config.files['project_settings']), fg='magenta')
+                click.secho(
+                    "Hint: file for configuration can be used: {}".format(
+                        config.files["project_settings"]
+                    ),
+                    fg="magenta",
+                )
 
     if not quiet:
-        click.secho("\n\nFound following extra settings files:\n", fg='cyan', bold=True)
+        click.secho("\n\nFound following extra settings files:\n", fg="cyan", bold=True)
 
     for file in _files:
         if not Path(file).exists():
@@ -104,16 +112,18 @@ def _collect_settings_files(config, quiet=False):
             Path(file).relative_to(root)
         except ValueError:
             if not quiet:
-                click.secho(f">>>>>>>>>>>>>>>>>>> {file} <<<<<<<<<<<<<<<<<", fg='cyan')
+                click.secho(f">>>>>>>>>>>>>>>>>>> {file} <<<<<<<<<<<<<<<<<", fg="cyan")
                 click.secho(file.read_text())
 
     return _files
 
+
 def _make_settings_file(outfile, setting_files):
     """
     Puts all settings into one settings file
     """
     from .myconfigparser import MyConfigParser
+
     c = MyConfigParser(outfile)
     for file in setting_files:
         if not file:
